        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 33 <strong>control</strong><br>0,1,2,3,4,6,8,9,11,12,14,15,16,19,21,22,23,24,25,28,30,31,33,34,35,36,38,39,42,43,47,48,49';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 18 <br>5,7,10,13,17,18,20,26,27,29,32,37,40,41,44,45,46,50';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 33 <strong>control</strong><br>0,1,2,3,4,6,8,9,11,12,14,15,16,19,21,22,23,24,25,28,30,31,33,34,35,36,38,39,42,43,47,48,49';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 18 <br>5,7,10,13,17,18,20,26,27,29,32,37,40,41,44,45,46,50';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 33 <strong>control</strong><br>0,1,2,3,4,6,8,9,11,12,14,15,16,19,21,22,23,24,25,28,30,31,33,34,35,36,38,39,42,43,47,48,49';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 18 <br>5,7,10,13,17,18,20,26,27,29,32,37,40,41,44,45,46,50';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 33 <strong>control</strong><br>0,1,2,3,4,6,8,9,11,12,14,15,16,19,21,22,23,24,25,28,30,31,33,34,35,36,38,39,42,43,47,48,49';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 18 <br>5,7,10,13,17,18,20,26,27,29,32,37,40,41,44,45,46,50';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 33 <strong>control</strong><br>0,1,2,3,4,6,8,9,11,12,14,15,16,19,21,22,23,24,25,28,30,31,33,34,35,36,38,39,42,43,47,48,49';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 18 <br>5,7,10,13,17,18,20,26,27,29,32,37,40,41,44,45,46,50';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>30</strong> miembros: 33 <strong>control</strong><br>0,1,2,3,4,6,8,9,11,12,14,15,16,19,21,22,23,24,25,28,30,31,33,34,35,36,38,39,42,43,47,48,49';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260524 a 12</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>7</strong> miembros: 18 <br>5,7,10,13,17,18,20,26,27,29,32,37,40,41,44,45,46,50';}
}
